@@ -43,7 +43,7 @@ namespace Kwave
 	explicit CurveWidget(QWidget *parent);
 
 	/** Destructor */
-	virtual ~CurveWidget();
+        virtual ~CurveWidget() Q_DECL_OVERRIDE;
 
 	/** Returns a command string for the curve. */
 	QString getCommand();
@@ -114,10 +114,10 @@ namespace Kwave
 
     protected slots:
 
-	void mousePressEvent(QMouseEvent * ) Q_DECL_OVERRIDE;
-	void mouseReleaseEvent(QMouseEvent * ) Q_DECL_OVERRIDE;
-	void mouseMoveEvent(QMouseEvent * ) Q_DECL_OVERRIDE;
-	void paintEvent(QPaintEvent *) Q_DECL_OVERRIDE;
+        virtual void mousePressEvent(QMouseEvent * ) Q_DECL_OVERRIDE;
+        virtual void mouseReleaseEvent(QMouseEvent * ) Q_DECL_OVERRIDE;
+        virtual void mouseMoveEvent(QMouseEvent * ) Q_DECL_OVERRIDE;
+        virtual void paintEvent(QPaintEvent *) Q_DECL_OVERRIDE;
 
     protected:
 
