@@ -50,13 +50,13 @@ namespace Kwave
 	                    sample_index_t pos);
 
 	/** Destructor */
-	virtual ~SelectionBorderItem();
+        virtual ~SelectionBorderItem() Q_DECL_OVERRIDE;
 
 	/**
 	 * Returns flags describing the possible interactions with this object
 	 * @see Kwave::ViewItem::Flags
 	 */
-	Kwave::ViewItem::Flags flags() const Q_DECL_OVERRIDE;
+        virtual Kwave::ViewItem::Flags flags() const Q_DECL_OVERRIDE;
 
 	/**
 	 * Can be overwritten to return a tooltip. The default implementation
@@ -65,19 +65,19 @@ namespace Kwave
 	 * @param ofs sample index the tooltip should refer to (unused)
 	 * @return an already localized tooltip
 	 */
-	QString toolTip(sample_index_t &ofs) Q_DECL_OVERRIDE;
+        virtual QString toolTip(sample_index_t &ofs) Q_DECL_OVERRIDE;
 
 	/**
 	 * Returns a mouse cursor used when moving the item
 	 */
-	QCursor mouseCursor() const Q_DECL_OVERRIDE;
+        virtual QCursor mouseCursor() const Q_DECL_OVERRIDE;
 
 	/**
 	 * handles updates when being moved with the mouse
 	 * @param mouse_pos position of the mouse, in pixel coordinates
 	 *                  relative to the parent widget
 	 */
-	void moveTo(const QPoint &mouse_pos) Q_DECL_OVERRIDE;
+        virtual void moveTo(const QPoint &mouse_pos) Q_DECL_OVERRIDE;
 
     private:
 
