@@ -45,16 +45,16 @@ namespace Kwave
 	              Kwave::SignalManager &signal_manager);
 
 	/** Destructor */
-	virtual ~SelectionItem();
+        virtual ~SelectionItem() Q_DECL_OVERRIDE;
 
 	/**
 	 * Returns flags describing the possible interactions with this object
 	 * @see Kwave::ViewItem::Flags
 	 */
-	Kwave::ViewItem::Flags flags() const Q_DECL_OVERRIDE;
+        virtual Kwave::ViewItem::Flags flags() const Q_DECL_OVERRIDE;
 
 	/** Starts a drag & drop operation. */
-	void startDragging() Q_DECL_OVERRIDE;
+        virtual void startDragging() Q_DECL_OVERRIDE;
 
     private:
 
