@@ -48,25 +48,25 @@ namespace Kwave
 	UndoDeleteTrack(Kwave::Signal &signal, unsigned int track);
 
 	/** Destructor */
-	virtual ~UndoDeleteTrack();
+        virtual ~UndoDeleteTrack() Q_DECL_OVERRIDE;
 
 	/**
 	 * Returns a verbose short description of the action.
 	 */
-	QString description() Q_DECL_OVERRIDE;
+        virtual QString description() Q_DECL_OVERRIDE;
 
 	/** @see UndoAction::undoSize() */
-	qint64 undoSize() Q_DECL_OVERRIDE;
+        virtual qint64 undoSize() Q_DECL_OVERRIDE;
 
 	/** @see UndoAction::redoSize() */
-	qint64 redoSize() Q_DECL_OVERRIDE;
+        virtual qint64 redoSize() Q_DECL_OVERRIDE;
 
 	/** @see UndoAction::store() */
-	bool store(SignalManager &manager) Q_DECL_OVERRIDE;
+        virtual bool store(SignalManager &manager) Q_DECL_OVERRIDE;
 
 	/** @see UndoAction::undo() */
-	Kwave::UndoAction *undo(Kwave::SignalManager &manager,
-	                        bool with_redo) Q_DECL_OVERRIDE;
+        virtual Kwave::UndoAction *undo(Kwave::SignalManager &manager,
+	                                bool with_redo) Q_DECL_OVERRIDE;
 
     protected:
 
