@@ -44,7 +44,7 @@ QString Kwave::UndoModifyMetaDataAction::description()
 
     QString name;
     {
-	const Kwave::MetaData &m = m_saved_data.values().first();
+	const Kwave::MetaData &m = m_saved_data.first();
 	if (m.hasProperty(Kwave::MetaData::STDPROP_TYPE))
 	    name = m[Kwave::MetaData::STDPROP_TYPE].toString();
     }
