@@ -40,16 +40,16 @@ namespace Kwave
  	AboutPlugin(QObject *parent, const QVariantList &args);
 
 	/** Destructor */
-	virtual ~AboutPlugin() {}
+        virtual ~AboutPlugin() Q_DECL_OVERRIDE {}
 
 	/** Returns the name of the plugin. */
-	QString name() const Q_DECL_OVERRIDE { return _("about"); }
+        virtual QString name() const Q_DECL_OVERRIDE { return _("about"); }
 
 	/**
 	* shows the about dialog,
 	* @see Kwave::Plugin::start()
 	*/
-	int start(QStringList &params) Q_DECL_OVERRIDE;
+        virtual int start(QStringList &params) Q_DECL_OVERRIDE;
 
     };
 }
