@@ -41,13 +41,13 @@ namespace Kwave
 	FlacCodecPlugin(QObject *parent, const QVariantList &args);
 
 	/** Destructor */
-	virtual ~FlacCodecPlugin();
+        virtual ~FlacCodecPlugin() Q_DECL_OVERRIDE;
 
 	/** Creates a new decoder */
-	QList<Kwave::Decoder *> createDecoder() Q_DECL_OVERRIDE;
+        virtual QList<Kwave::Decoder *> createDecoder() Q_DECL_OVERRIDE;
 
 	/** Creates a new encoder */
-	QList<Kwave::Encoder *> createEncoder() Q_DECL_OVERRIDE;
+        virtual QList<Kwave::Encoder *> createEncoder() Q_DECL_OVERRIDE;
 
     private:
 	/** static codec container */
