@@ -39,7 +39,7 @@ namespace Kwave
 	SelectDateDialog(QWidget *parent, QDate &date);
 
 	/** Destructor */
-	virtual ~SelectDateDialog();
+        virtual ~SelectDateDialog() Q_DECL_OVERRIDE;
 
 	/** Returns the selected date */
 	virtual QDate date();
@@ -47,7 +47,7 @@ namespace Kwave
     public slots:
 
 	/** applies the settings and closes the dialog (OK button) */
-	void accept() Q_DECL_OVERRIDE;
+        virtual void accept() Q_DECL_OVERRIDE;
 
     private:
 
